@@ -492,12 +492,23 @@ def AddVolumeMultipleEndpointsArg(parser):
   )
 
 
-def AddVolumeTieringPolicyArg(parser, messages):
+def AddVolumeTieringPolicyArg(parser, messages, release_track):
   """Adds the --tiering-policy arg to the arg parser."""
-  tiering_policy_arg_spec = {
-      'tier-action': messages.TieringPolicy.TierActionValueValuesEnum,
-      'cooling-threshold-days': int,
-  }
+  if (release_track == calliope_base.ReleaseTrack.BETA or
+      release_track == calliope_base.ReleaseTrack.ALPHA):
+    tiering_policy_arg_spec = {
+        'tier-action': messages.TieringPolicy.TierActionValueValuesEnum,
+        'cooling-threshold-days': int,
+        'enable-hot-tier-bypass-mode': arg_parsers.ArgBoolean(
+            truthy_strings=netapp_util.truthy,
+            falsey_strings=netapp_util.falsey,
+        ),
+    }
+  else:
+    tiering_policy_arg_spec = {
+        'tier-action': messages.TieringPolicy.TierActionValueValuesEnum,
+        'cooling-threshold-days': int,
+    }
   tiering_policy_help = """\
       Tiering Policy contains auto tiering policy on a volume.
 
@@ -518,7 +529,9 @@ can be range from 7-183. Default is 31.
   )
 
 
-def AddVolumeHybridReplicationParametersArg(parser, messages, hidden=False):
+def AddVolumeHybridReplicationParametersArg(
+    parser, messages, release_track=calliope_base.ReleaseTrack.GA, hidden=False
+):
   """Adds the --hybrid-replication-parameters arg to the arg parser."""
   hybrid_replication_parameters_arg_spec = {
       'replication': str,
@@ -530,17 +543,25 @@ def AddVolumeHybridReplicationParametersArg(parser, messages, hidden=False):
       ),
       'cluster-location': str,
       'description': str,
-      'replication-schedule': (
-          messages.HybridReplicationParameters.ReplicationScheduleValueValuesEnum
-      ),
-      'hybrid-replication-type': (
-          messages.HybridReplicationParameters.HybridReplicationTypeValueValuesEnum
-      ),
-      'large-volume-constituent-count': int,
       'labels': arg_parsers.ArgList(
           min_length=1, element_type=str, custom_delim_char='#'
       ),
   }
+  # TODO(b/425281073): Remove this check once the bidirectional snapmirror
+  # is AGA.
+  if release_track in [
+      calliope_base.ReleaseTrack.BETA, calliope_base.ReleaseTrack.ALPHA,
+  ]:
+    hybrid_replication_parameters_arg_spec['replication-schedule'] = (
+        messages.HybridReplicationParameters.ReplicationScheduleValueValuesEnum
+    )
+    hybrid_replication_parameters_arg_spec['hybrid-replication-type'] = (
+        messages.HybridReplicationParameters.HybridReplicationTypeValueValuesEnum
+    )
+    hybrid_replication_parameters_arg_spec[
+        'large-volume-constituent-count'
+    ] = int
+
   hybrid_replication_parameters_help = """\
   Hybrid Replication Parameters contains hybrid replication parameters on a volume.
 
@@ -573,6 +594,69 @@ def AddVolumeHybridReplicationParametersArg(parser, messages, hidden=False):
   )
 
 
+def AddVolumeCacheParametersArg(parser, hidden=False):
+  """Adds the --cache-parameters arg to the arg parser."""
+  cache_parameters_arg_spec = {
+      'peer-volume-name': str,
+      'peer-cluster-name': str,
+      'peer-svm-name': str,
+      'peer-ip-addresses': arg_parsers.ArgList(
+          min_length=1, element_type=str, custom_delim_char='#'
+      ),
+      'enable-global-file-lock': arg_parsers.ArgBoolean(
+          truthy_strings=netapp_util.truthy, falsey_strings=netapp_util.falsey
+      ),
+      'cache-config': arg_parsers.ArgList(
+          max_length=3, element_type=arg_parsers.ArgDict(),
+          custom_delim_char='#'
+      ),
+  }
+  cache_parameters_help = """\
+  Cache Parameters contains cache parameters of a volume.
+
+      Cache Parameters will have the following format
+      `--cache-parameters=peer-volume-name=PEER_VOLUME_NAME,
+        peer-cluster-name=PEER_CLUSTER_NAME,
+        peer-svm-name=PEER_SVM_NAME,
+        peer-ip-addresses=[PEER-IP-ADDRESS1#PEER-IP-ADDRESS2#...],
+        enable-global-file-lock=ENABLE_GLOBAL_FILE_LOCK,
+        cache-config=CACHE_CONFIG`
+
+      *peer-volume-name*::: Name of the user's local source volume
+      *peer-cluster-name*::: Name of the user's local source cluster
+      *peer-svm-name*::: Name of the user's local source vserver svm
+      *peer-ip-addresses*::: Hashtag-separated(#) list of IP addresses
+      *enable-global-file-lock*::: If true, enable global file lock
+      *cache-config*::: Cache-config as a hashtag-separated(#) list of key-value pairs
+  """
+  parser.add_argument(
+      '--cache-parameters',
+      type=arg_parsers.ArgDict(spec=cache_parameters_arg_spec),
+      help=cache_parameters_help,
+      hidden=hidden,
+  )
+
+
+def AddVolumeRestoreFileListArg(parser, required=True):
+  """Adds the --file-list arg to the arg parser."""
+  parser.add_argument(
+      '--file-list',
+      type=arg_parsers.ArgList(min_length=1, element_type=str),
+      metavar='FILE_LIST',
+      required=required,
+      help="""List of files to be restored in the form of their absolute path as in source volume.""",
+  )
+
+
+def AddVolumeRestoreDestinationPathArg(parser, required=True):
+  """Adds the --restore-destination-path arg to the arg parser."""
+  parser.add_argument(
+      '--restore-destination-path',
+      type=str,
+      required=required,
+      help="""Name of the absolute directory path in the destination volume..""",
+  )
+
 ## Helper functions to combine Volumes args / flags for gcloud commands #
 
 
@@ -609,8 +693,13 @@ def AddVolumeCreateArgs(parser, release_track):
   ):
     AddVolumeBackupConfigArg(parser)
     AddVolumeSourceBackupArg(parser)
-  AddVolumeTieringPolicyArg(parser, messages)
-  AddVolumeHybridReplicationParametersArg(parser, messages)
+  AddVolumeTieringPolicyArg(parser, messages, release_track)
+  AddVolumeHybridReplicationParametersArg(parser, messages, release_track)
+  if (
+      release_track == calliope_base.ReleaseTrack.BETA
+      or release_track == calliope_base.ReleaseTrack.ALPHA
+  ):
+    AddVolumeCacheParametersArg(parser, hidden=True)
   labels_util.AddCreateLabelsFlags(parser)
 
 
@@ -654,5 +743,16 @@ def AddVolumeUpdateArgs(parser, release_track):
   ):
     AddVolumeBackupConfigArg(parser)
     AddVolumeSourceBackupArg(parser)
-  AddVolumeTieringPolicyArg(parser, messages)
+  AddVolumeTieringPolicyArg(parser, messages, release_track)
   labels_util.AddUpdateLabelsFlags(parser)
+
+
+def AddVolumeRestoreFromBackupArg(parser, required=True):
+  """Adds the --backup arg to the arg parser."""
+  concept_parsers.ConceptParser.ForResource(
+      '--backup',
+      flags.GetBackupResourceSpec(positional=False),
+      required=required,
+      flag_name_overrides={'location': ''},
+      group_help='The Backup from which files are restored back to the Volume.',
+  ).AddToParser(parser)
