@@ -65,6 +65,8 @@ auto_flags = [
     'enableAuthorizedNetworksOnPrivateEndpoint',
     'enableAutoIpam',
     'enableK8sTokensViaDns',
+    'enableDefaultComputeClass',
+    'enableK8sCertsViaDns',
 ]
 
 # Change default flag values in create-auto
@@ -105,6 +107,7 @@ def AddAutoFlags(parser, release_track):
   flags.AddClusterTierFlag(parser)
   flags.AddKubecontextOverrideFlag(parser)
   flags.AddAnonymousAuthenticationConfigFlag(parser)
+  flags.AddEnableLegacyLustrePortFlag(parser, hidden=True)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
